from rtde import rtde, rtde_config
import rtde
import sys


class ForceInjector:
    def __init__(self, robot_ip="127.0.0.1", robot_port=30004, config_file="force_injection.xml"):
        self.robot = rtde.RTDE(robot_ip, robot_port)
        self.robot.connect()
        configuration = rtde_config.ConfigFile(config_file)

        sensor_names, sensor_types = configuration.get_recipe('sensor')
        self.sensor_data = self.robot.send_input_setup(sensor_names, sensor_types)

        ft_names, ft_types = configuration.get_recipe('robot_force_torque')
        self.ft_data = self.robot.send_output_setup(ft_names, ft_types)

        if not self.robot.send_start():
            print("Error robot.send_start() failed")
            sys.exit()

    def inject(self, injected_force):
        self.sensor_data.external_force_torque = injected_force
        self.robot.send(self.sensor_data)
        # robot.send(watchdog)


if __name__ == "__main__":
    force_injector = ForceInjector(config_file="force_injection.xml")
    from time import time
    start = time()

    while time() - start < 100:
        force = [0, 0, 0, 1, 0, 0]
        force_injector.inject(force)
        print("Force: ", force)
    print("Stopping")
